| Title: | Easy and Interactive Time Series Visualization |
|---|---|
| Description: | An 'RStudio' add-in to visualize time series. Time series are searched in the global environment as data.frame objects with a column of type date and a column of type numeric. Interactive charts are produced using 'plotly' package. |
| Authors: | Marta Peroni [aut], Emanuele Fabbiani [cre] |
| Maintainer: | Emanuele Fabbiani <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-24 07:32:58 UTC |
| Source: | https://github.com/xtreamsrl/tsviz |
A dataset closing prices for Litecoin, Bitcoin and Ethereum on 1174 days, between 2016-04-01 and 2019-07-01. Prices are recorded in US dollars.
crypto_pricescrypto_prices
A data frame with 1174 rows and 4 variables:
Date: date when the price was recorded
LTC: closing price of Litecoin
BTC: closing price of Bitconin
EHT: closing price of Ethereum
An RStudio addin to visualize time series.
Time series are supposed to be contained into a data.frame object in the global environment,
with the following format:
a column of type Date
one of more numeric columns
tsviz()tsviz()
if(interactive()){ prices <- tsviz::crypto_prices tsviz::tsviz() }if(interactive()){ prices <- tsviz::crypto_prices tsviz::tsviz() }